==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/inputs/AddonProfilesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.inputs

import com.pulumi.azurenative.hybridcontainerservice.inputs.AddonProfilesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Addon configurations
 * @property config Config - Key-value pairs for configuring an add-on.
 * @property enabled Enabled - Whether the add-on is enabled or not.
 */
public data class AddonProfilesArgs(
    public val config: Output<Map<String, String>>? = null,
    public val enabled: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridcontainerservice.inputs.AddonProfilesArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridcontainerservice.inputs.AddonProfilesArgs =
        com.pulumi.azurenative.hybridcontainerservice.inputs.AddonProfilesArgs.builder()
            .config(config?.applyValue({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() }))
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AddonProfilesArgs].
 */
@PulumiTagMarker
public class AddonProfilesArgsBuilder internal constructor() {
    private var config: Output<Map<String, String>>? = null

    private var enabled: Output<Boolean>? = null

    /**
     * @param value Config - Key-value pairs for configuring an add-on.
     */
    @JvmName("achhlktcglmiqomi")
    public suspend fun config(`value`: Output<Map<String, String>>) {
        this.config = value
    }

    /**
     * @param value Enabled - Whether the add-on is enabled or not.
     */
    @JvmName("iciycampjtwmhfcn")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Config - Key-value pairs for configuring an add-on.
     */
    @JvmName("atsqflqnlsjbypki")
    public suspend fun config(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.config = mapped
    }

    /**
     * @param values Config - Key-value pairs for configuring an add-on.
     */
    @JvmName("ropshneuboitvfph")
    public fun config(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.config = mapped
    }

    /**
     * @param value Enabled - Whether the add-on is enabled or not.
     */
    @JvmName("oimekbtidladqmcm")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build(): AddonProfilesArgs = AddonProfilesArgs(
        config = config,
        enabled = enabled,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/inputs/AddonProfilesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.inputs

import com.pulumi.azurenative.hybridcontainerservice.inputs.AddonProfilesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Addon configurations
 * @property config Config - Key-value pairs for configuring an add-on.
 * @property enabled Enabled - Whether the add-on is enabled or not.
 */
public data class AddonProfilesArgs(
    public val config: Output<Map<String, String>>? = null,
    public val enabled: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridcontainerservice.inputs.AddonProfilesArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridcontainerservice.inputs.AddonProfilesArgs =
        com.pulumi.azurenative.hybridcontainerservice.inputs.AddonProfilesArgs.builder()
            .config(config?.applyValue({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() }))
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AddonProfilesArgs].
 */
@PulumiTagMarker
public class AddonProfilesArgsBuilder internal constructor() {
    private var config: Output<Map<String, String>>? = null

    private var enabled: Output<Boolean>? = null

    /**
     * @param value Config - Key-value pairs for configuring an add-on.
     */
    @JvmName("lhhhrajmhloijywc")
    public suspend fun config(`value`: Output<Map<String, String>>) {
        this.config = value
    }

    /**
     * @param value Enabled - Whether the add-on is enabled or not.
     */
    @JvmName("fuqhcjimmsfpbfle")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Config - Key-value pairs for configuring an add-on.
     */
    @JvmName("bnakkwfuwlajborr")
    public suspend fun config(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.config = mapped
    }

    /**
     * @param values Config - Key-value pairs for configuring an add-on.
     */
    @JvmName("rjhhysyneyvkaqpa")
    public fun config(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.config = mapped
    }

    /**
     * @param value Enabled - Whether the add-on is enabled or not.
     */
    @JvmName("mjiqapenmyxnaxfv")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build(): AddonProfilesArgs = AddonProfilesArgs(
        config = config,
        enabled = enabled,
    )
}
